@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2017-01-15'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -202,7 +202,7 @@ $SPEC{upload_files} = {
     v => 1.1,
     summary => 'Upload file(s)',
     args_rels => {
-        choose_one => [qw/delay group_delay/],
+        choose_one => [qw/delay/],
     },
     args => {
         %common_args,
@@ -222,29 +222,6 @@ currently might choke with SQLite database locking problem and thus fail to
 index your releases. Giving a delay of say 2-3 minutes (120-180 seconds) between
 files will alleviate this problem.
 
-_
-        },
-        group_delay => {
-            summary => 'Pause a number of seconds between groups of files',
-            schema => 'duration*',
-            description => <<'_',
-
-As an alternative to the `delay` option, you can also use this option. This will
-group the files to be uploaded by versions and prevent files of the same dist
-and different versions to be uploaded too close to one another, as this might
-cause indexing problem too. For example, suppose you're uploading Foo-1.zip
-Foo-2.zip Foo-3.zip Bar-1.zip Baz-1.zip Baz-2.zip. The files will be uploaded in
-this order:
-
-    upload: Foo-1.zip Bar-1.zip Baz-1.zip
-    group delay
-    upload: Foo-2.zip Baz-2.zip
-    group delay
-    upload: Foo-3.zip
-
-As with the `delay` option, it is recommended that if you upload several files
-at once, you set this option to 2-3 minutes (120-180 seconds).
-
 _
         },
     },
@@ -254,44 +231,15 @@ sub upload_files {
     require File::Basename;
 
     my %args = @_;
-    my $files0 = $args{files}
+    my $files = $args{files}
         or return [400, "Please specify at least one file"];
     my $subdir = $args{subdir} // '';
 
-    # probably group it into versions
-    my @files;
-    if ($args{group_delay}) {
-        my %files_by_dist; # key=distname, val=[file, ...]
-        my $max_num_vers = 0;
-        for my $file (sort @$files0) {
-            my ($dist, $ver, $is_dev) = _parse_release_filename($file);
-            if (!$dist) {
-                ($dist, $ver) = ("", 0);
-            }
-            $files_by_dist{$dist} //= [];
-            push @{ $files_by_dist{$dist} }, $file;
-            $max_num_vers = @{ $files_by_dist{$dist} }
-                if $max_num_vers < @{ $files_by_dist{$dist} };
-        }
-        for my $i (1..$max_num_vers) {
-            for my $dist (keys %files_by_dist) {
-                next unless @{ $files_by_dist{$dist} } >= $i;
-                push @files, {
-                    group => $i,
-                    file => $files_by_dist{$dist}[$i-1],
-                };
-            }
-        }
-    } else {
-        @files = map { +{group=>1, file=>$_} } @$files0;
-    }
-
     my $envres = envresmulti();
 
     my $i = 0;
     my $prev_group = 0;
-    for my $ent (@files) {
-        my $file = $ent->{file};
+    for my $file (@$files) {
         my $res;
         {
             unless (-f $file) {
@@ -345,18 +293,12 @@ sub upload_files {
       DELAY:
         {
             # it's the last file, no point in delaying, just exit
-            last if ++$i >= @files;
+            last if ++$i >= @$files;
             if ($args{delay}) {
                 $log->tracef("Sleeping between files for %d second(s) ...", $args{delay});
                 sleep $args{delay};
                 last;
             }
-            if ($args{group_delay} &&
-                    $ent->{group} > 1 && $prev_group != $ent->{group}) {
-                $log->tracef("Sleeping between group for %d second(s) ...", $args{group_delay});
-                sleep $args{group_delay};
-                $prev_group = $ent->{group};
-            }
         }
     }
     $envres->as_struct;
@@ -909,7 +851,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.34 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-12.
+This document describes version 0.35 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-15.
 
 =head1 SYNOPSIS
 
@@ -1412,26 +1354,6 @@ files will alleviate this problem.
 
 File names/wildcard patterns.
 
-=item * B<group_delay> => I<duration>
-
-Pause a number of seconds between groups of files.
-
-As an alternative to the C<delay> option, you can also use this option. This will
-group the files to be uploaded by versions and prevent files of the same dist
-and different versions to be uploaded too close to one another, as this might
-cause indexing problem too. For example, suppose you're uploading Foo-1.zip
-Foo-2.zip Foo-3.zip Bar-1.zip Baz-1.zip Baz-2.zip. The files will be uploaded in
-this order:
-
- upload: Foo-1.zip Bar-1.zip Baz-1.zip
- group delay
- upload: Foo-2.zip Baz-2.zip
- group delay
- upload: Foo-3.zip
-
-As with the C<delay> option, it is recommended that if you upload several files
-at once, you set this option to 2-3 minutes (120-180 seconds).
-
 =item * B<password>* => I<str>
 
 PAUSE password.
